==> weifund-util-0.0.1.tgz: package/README.md <==
# weifund-util

[![NPM version](http://img.shields.io/npm/v/weifund-util.svg)](https://www.npmjs.org/package/weifund-util) [![Build status](https://ci.appveyor.com/api/projects/status/wwajr0886e00g8je/branch/master?svg=true)](https://ci.appveyor.com/project/weifund/weifund-util/branch/master) [![Coverage Status](https://coveralls.io/repos/github/weifund/weifund-util/badge.svg?branch=master)](https://coveralls.io/github/weifund/weifund-util?branch=master) [![NPM Downloads](https://img.shields.io/npm/dm/weifund-util.svg)](https://www.npmjs.org/package/weifund-util)

A utility methods for the WeiFund client and library. Note, still in heavy development.

## Install

```
npm install --save weifund-util
```

## About

WeiFund uses a small set of methods to handle its campaign and registry data. There are many small utility methods that are needed to make these methods function. This library contains those methods.

## Usage

```
const utils = require('weifund-utils');

console.log(utils);

/* results in:
{
  isBigNumber: isBigNumber,
  etherScanAddressUrl: etherScanAddressUrl,
  etherScanTxHashUrl: etherScanTxHashUrl,
  parseCampaignRegistryData: parseCampaignRegistryData,
  buildInputsArray: buildInputsArray,
  oneDay: oneDay,
  parseSolidityMethodInterface: parseSolidityMethodInterface,
  emptyWeb3Address: emptyWeb3Address,
  parseMethodABIObject: parseMethodABIObject,
  capitalizeFirstLetter: capitalizeFirstLetter,
  filterXSSObject: filterXSSObject,
  nameContainsIDProperties: nameContainsIDProperties,
  parseSolidityMethodName: parseSolidityMethodName,
};
*/
```

## Contributing

Please help better the ecosystem by submitting issues and pull requests to weifund-util. We need all the help we can get to build the absolute best linting standards and utilities. We follow the AirBNB linting standard. Please read more about contributing to `weifund-util` in the `CONTRIBUTING.md`.

## Guides

You'll find more detailed information on using weifund-util and tailoring it to your needs in our guides:

- [User guide](docs/user-guide.md) - Usage, configuration, FAQ and complementary tools.
- [Developer guide](docs/developer-guide.md) - Contributing to weifund-util and writing your own plugins & formatters.

## Help out

There is always a lot of work to do, and will have many rules to maintain. So please help out in any way that you can:

- Create, enhance, and debug rules (see our guide to ["Working on rules"](CONTRIBUTING.md)).
- Improve documentation.
- Chime in on any open issue or pull request.
- Open new issues about your ideas for making stylelint better, and pull requests to show us how your idea works.
- Add new tests to *absolutely anything*.
- Work on [improving performance of rules](docs/developer-guide/benchmarks.md).
- Create or contribute to ecosystem tools, like the plugins for Atom and Sublime Text.
- Spread the word.

Please consult our [Code of Conduct](CODE_OF_CONDUCT.md) and [Contributing](CONTRIBUTING.md) docs before helping out.

We communicate via [issues](https://github.com/weifund/weifund-util/issues) and [pull requests](https://github.com/weifund/weifund-util/pulls).

## Important documents

- [Changelog](CHANGELOG.md)
- [Contributing Guidelines](CONTRIBUTING.md)
- [Code of Conduct](CODE_OF_CONDUCT.md)
- [License](https://raw.githubusercontent.com/weifund/weifund-util/master/LICENSE)

## Licence

```
The MIT License

Copyright (c) 2016 WeiFund. www.weifund.io

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
```

==> weifund-util-0.1.0.tgz: package/README.md <==
# weifund-util

[![NPM version](http://img.shields.io/npm/v/weifund-util.svg)](https://www.npmjs.org/package/weifund-util) [![Build status](https://ci.appveyor.com/api/projects/status/wwajr0886e00g8je/branch/master?svg=true)](https://ci.appveyor.com/project/weifund/weifund-util/branch/master) [![Coverage Status](https://coveralls.io/repos/github/weifund/weifund-util/badge.svg?branch=master)](https://coveralls.io/github/weifund/weifund-util?branch=master) [![NPM Downloads](https://img.shields.io/npm/dm/weifund-util.svg)](https://www.npmjs.org/package/weifund-util)

A utility methods for the WeiFund client and library. Note, still in heavy development.

## Install

```
npm install --save weifund-util
```

## About

WeiFund uses a small set of methods to handle its campaign and registry data. There are many small utility methods that are needed to make these methods function. This library contains those methods.

## Usage

```
const utils = require('weifund-util');

console.log(utils);

/* results in:
{
  isBigNumber: isBigNumber,
  etherScanAddressUrl: etherScanAddressUrl,
  etherScanTxHashUrl: etherScanTxHashUrl,
  parseCampaignRegistryData: parseCampaignRegistryData,
  buildInputsArray: buildInputsArray,
  oneDay: oneDay,
  parseSolidityMethodInterface: parseSolidityMethodInterface,
  emptyWeb3Address: emptyWeb3Address,
  parseMethodABIObject: parseMethodABIObject,
  capitalizeFirstLetter: capitalizeFirstLetter,
  filterXSSObject: filterXSSObject,
  nameContainsIDProperties: nameContainsIDProperties,
  parseSolidityMethodName: parseSolidityMethodName,
};
*/
```

## Contributing

Please help better the ecosystem by submitting issues and pull requests to weifund-util. We need all the help we can get to build the absolute best linting standards and utilities. We follow the AirBNB linting standard. Please read more about contributing to `weifund-util` in the `CONTRIBUTING.md`.

## Guides

You'll find more detailed information on using weifund-util and tailoring it to your needs in our guides:

- [User guide](docs/user-guide.md) - Usage, configuration, FAQ and complementary tools.
- [Developer guide](docs/developer-guide.md) - Contributing to weifund-util and writing your own plugins & formatters.

## Help out

There is always a lot of work to do, and will have many rules to maintain. So please help out in any way that you can:

- Create, enhance, and debug rules (see our guide to ["Working on rules"](CONTRIBUTING.md)).
- Improve documentation.
- Chime in on any open issue or pull request.
- Open new issues about your ideas for making stylelint better, and pull requests to show us how your idea works.
- Add new tests to *absolutely anything*.
- Work on [improving performance of rules](docs/developer-guide/benchmarks.md).
- Create or contribute to ecosystem tools, like the plugins for Atom and Sublime Text.
- Spread the word.

Please consult our [Code of Conduct](CODE_OF_CONDUCT.md) and [Contributing](CONTRIBUTING.md) docs before helping out.

We communicate via [issues](https://github.com/weifund/weifund-util/issues) and [pull requests](https://github.com/weifund/weifund-util/pulls).

## Important documents

- [Changelog](CHANGELOG.md)
- [Contributing Guidelines](CONTRIBUTING.md)
- [Code of Conduct](CODE_OF_CONDUCT.md)
- [License](https://raw.githubusercontent.com/weifund/weifund-util/master/LICENSE)

## Licence

```
The MIT License

Copyright (c) 2016 WeiFund. www.weifund.io

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
```
